/*
 * Java
 *
 * Copyright 2008-2022 IS2T. All rights reserved.
 * IS2T PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */
package com.is2t.elflw.input;

import com.is2t.elflw.ElfConstants;

import ej.annotation.Nullable;

public class ElfLoaderError extends RuntimeException implements ErrorMessagesConstants {

	public int kind;
	@Nullable
	public char[][] parts;

	public ElfLoaderError() {

	}

	public ElfLoaderError inconsistentLibrary(int errorCode) {
		this.kind = ElfLoaderErrorInconsistentLibrary;
		this.parts = new char[][] { String.valueOf(errorCode).toCharArray() };
		return this;
	}

	public String[] getMessages() {
		return ErrorMessages.messages;
	}

	public ElfLoaderError invalidHeaderType(int type, int expectedType) {
		this.kind = ElfLoaderErrorInvalidHeaderType;
		this.parts = new char[][] { toHexString(type).toCharArray(), toHexString(expectedType).toCharArray() };
		return this;
	}

	public ElfLoaderError invalidHeader(int internalCode) {
		this.kind = ElfLoaderErrorInvalidHeader;
		this.parts = new char[][] { Integer.toString(internalCode).toCharArray() };
		return this;
	}

	public ElfLoaderError unknownSectionType(int sectionIndex, int type) {
		this.kind = ElfLoaderErrorUnknownSectionType;
		this.parts = new char[][] { Integer.toString(sectionIndex).toCharArray(), toHexString(type).toCharArray() };
		return this;
	}

	public ElfLoaderError unknownRelocationCode(int code) {
		this.kind = ElfLoaderUnknownRelocationCode;
		this.parts = new char[][] { toHexString(code).toCharArray() };
		return this;
	}

	public String outputName() {
		return "ELF LOADER ERROR";
	}

	public ElfLoaderError unsupportedArchitecture(int machine, int expectedMachine) {
		this.kind = ElfLoaderErrorUnsupportedArchitecture;
		this.parts = new char[][] { toHexString(machine).toCharArray(), toHexString(expectedMachine).toCharArray() };
		return this;
	}

	public ElfLoaderError invalidELFSignature(byte[] elfSignature) {
		this.kind = ElfLoaderErrorUnsupportedArchitecture;
		this.parts = new char[][] { (toHexString(elfSignature[ElfConstants.ELFMAG0])
				+ toHexString(elfSignature[ElfConstants.ELFMAG1]) + toHexString(elfSignature[ElfConstants.ELFMAG2])
				+ toHexString(elfSignature[ElfConstants.ELFMAG3])).toCharArray() };
		return this;
	}

	private String toHexString(int i) {
		return "0x" + Integer.toHexString(i & 0xff);
	}

	@Override
	@Nullable
	public String getMessage() {
		StringBuffer sb = new StringBuffer("ELF ERROR[");
		sb.append(this.kind);
		sb.append("]");
		char[][] parts = this.parts;
		if (parts != null) {
			sb.append('(');
			int nbParts = parts.length;
			for (int i = -1; ++i < nbParts;) {
				if (i > 0) {
					sb.append(',');
				} else {
					char[] part = parts[i];
					assert part != null;
					sb.append(part);
				}
			}
			sb.append(')');
		}
		return sb.toString();
	}
}
