/*
 * Java
 *
 * Copyright 2008-2022 IS2T. All rights reserved.
 * IS2T PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */
package com.is2t.elflw.nodes;

import com.is2t.elflw.ElfGenerator;
import com.is2t.elflw.allocator.MemoryBlock;

/**
 * Dynamic section (i.e. physical size is 0)
 */
public class DynamicAllocationSection extends Section implements AllocationSection{

	public MemoryBlock data;

	public DynamicAllocationSection(int alignment, MemoryBlock data) {
		super(alignment);
		this.data = data;
	}

	@Override
	public void generateUsing(ElfGenerator gen) {
		gen.generateDynamicAllocationSection(this);
	}

	@Override
	public int size(){
		return 0;
	}

	@Override
	public int memSize() {
		return data.getSize();
	}

	public int imageSize() {
		return size(); // by definition of this kind of section, size == 0 in the ELF file
	}

	public boolean isProgramImagePart() {
		return false; // NOBITS => false (only a mean at runtime)
	}

	@Override
	public MemoryBlock getMemoryBlock(){
		return data;
	}

	@Override
	public long getRelocatedAddress() {
		return data.getAddress();
	}

}
