/*
 * Java
 *
 * Copyright 2008-2022 IS2T. All rights reserved.
 * IS2T PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */
package com.is2t.elflw.nodes;

import com.is2t.elflw.ElfGenerator;
import com.is2t.elflw.allocator.MemoryBlock;

/**
 * Section that contains target specific raw binary program bytes (asm instructions, data)
 */
public class ProgAllocationSection extends ProgSection implements AllocationSection {

	/**
	 * the 0 based index of the section within the {@link ElfUnit}
	 */
	private final int sectionIndex;

	/** Target specific data */
	public MemoryBlock data;

	private final MemoryBlock relocatedData;

	public ProgAllocationSection(int sectionIndex, int alignment, MemoryBlock data, MemoryBlock relocatedData) {
		super(alignment);
		this.sectionIndex = sectionIndex;
		this.data = data;
		this.relocatedData = relocatedData;
	}

	@Override
	public void generateUsing(ElfGenerator gen) {
		gen.generateProgAllocationSection(this);
	}

	@Override
	public int memSize() {
		return size();
	}

	@Override
	public MemoryBlock getMemoryBlock() {
		return this.data;
	}

	/**
	 * @return the relocated memory block descriptor
	 */
	public MemoryBlock getRelocatedMemoryBlock() {
		return this.relocatedData;
	}

	@Override
	public long getRelocatedAddress() {
		return this.relocatedData.getAddress();
	}

	/**
	 * @return the 0 based index of the section within the {@link ElfUnit}
	 */
	public int getSectionIndex() {
		return this.sectionIndex;
	}

	@Override
	public int size() {
		return this.data.getSize();
	}
}
