/*
 * Java
 *
 * Copyright 2008-2022 IS2T. All rights reserved.
 * IS2T PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */
package com.is2t.elflw.nodes;

import com.is2t.elflw.ElfConstants;
import com.is2t.elflw.ElfGenerator;

import ej.annotation.Nullable;

/**
 * A relocation section is a section which contains instructions to relocate another section When no targetSection is
 * specified, relocation entries offset are applied on the whole elfUnit
 */
public class RelocationSection extends Section {

	public boolean withAddend; // When true, this is a RELA section which contains only RelocationEntryAddend
	@Nullable
	public SymbolTableSection symbolTable;
	@Nullable
	public ProgSection targetSection;

	public byte[] data;

	public RelocationSection(int alignment, boolean withAddend, byte[] data) {
		super(alignment);
		this.withAddend = withAddend;
		this.data = data;
	}

	@Override
	public void generateUsing(ElfGenerator gen) {
		gen.generateRelocationSection(this);
	}

	@Override
	public int size() {
		return this.data.length;
	}

	public int entrySize() {
		return this.withAddend ? ElfConstants.SizeofRelocationEntryAddend : ElfConstants.SizeofRelocationEntry;
	}

	public int nbEntries() {
		return this.data.length / entrySize();
	}
}
