/*
 * Java
 *
 * Copyright 2008-2022 IS2T. All rights reserved.
 * IS2T PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */
package com.is2t.elflw.nodes;

import com.is2t.elflw.ElfConstants;
import com.is2t.elflw.ElfGenerator;

import ej.annotation.Nullable;

/**
 * Symbol table should respect the following layout (see Elf Spec SymbolTable layout conventions (819-0690.pdf, p251))
 * <li>index 0 : null symbol (NO_TYPE)</li>
 * <li>one symbol per section (STT_SECTION)</li>
 * <li>Sort all local symbols per STT_FILE that defines it</li>
 * <li>Then All global symbols</li>
 */
public class SymbolTableSection extends Section {

	public byte[] data;
	@Nullable
	public StringSection stringSection;

	public SymbolTableSection(int alignment, byte[] data) {
		super(alignment);
		this.data = data;
	}

	@Override
	public void generateUsing(ElfGenerator gen) {
		gen.generateSymbolTableSection(this);
	}

	@Override
	public int size() {
		return this.data.length;
	}

	public int entrySize() {
		return ElfConstants.SizeofSymbolTableEntry;
	}

	public int nbEntries() {
		return this.data.length / entrySize();
	}
}
