/*
 * Java
 *
 * Copyright 2022 IS2T. All rights reserved.
 * IS2T PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */
package com.is2t.kf;

import com.is2t.elflw.allocator.MemoryBlock;

/**
 * A {@link MemoryBlock} directly mapped to an absolute memory address. Only the data transfer is implemented (no
 * read/write operations).
 */
public class MappedMemoryBlock implements MemoryBlock {

	private final long startAddress;
	private final int size;

	public MappedMemoryBlock(long startAddress, int size) {
		this.startAddress = startAddress;
		this.size = size;
	}

	@Override
	public int getSize() {
		return this.size;
	}

	@Override
	public boolean copyFrom(byte[] src, int srcOffset, int dstOffset, int length) {
		return DynamicLoaderNatives.copyByteArrayToROM(this.startAddress + dstOffset, src, srcOffset, length);
	}

	@Override
	public void copyTo(int srcOffset, byte[] dst, int dstOffset, int length) {
		throw new AssertionError();
	}

	@Override
	public long getAddress() {
		return this.startAddress;
	}

}
