/*
 * Copyright (c) 2014, Oracle and/or its affiliates. All rights reserved.
 * Copyright 2014-2022 MicroEJ Corp. This file has been modified and/or created by MicroEJ Corp.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation. The Copyright holder(s) designates
 * this particular file as subject to the "Classpath" exception as provided
 * by the Copyright holder(s) in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact the Copyright holder(s) if you need additional information
 * or have any questions.
 * (if Oracle: 500 Oracle Parkway, Redwood Shores, CA 94065 USA or visit www.oracle.com)
 */

package com.is2t.support.net.natives;

import java.net.MulticastSocket;

import com.is2t.errors.NetErrors;

import ej.sni.NativeIOException;

/**
 * {@link MulticastSocket} related natives.
 */
public class MulticastSocketChannelNatives {

	/**
	 * Get the default time-to-live for multicast packets sent out on the channel.
	 * 
	 * @param nativeFD
	 *            the datagram socket file descriptor
	 * @return the default time-to-live value
	 * @throws NativeIOException
	 *             if an error occurs.
	 * @see {@link NetErrors} for error codes
	 */
	public static native int getTimeToLive(int nativeFD) throws NativeIOException;

	/**
	 * Set the default time-to-live for multicast packets sent out on this channel in order to control the scope of the
	 * multicasts. The ttl <B>must</B> be in the range {@code  0 <= ttl <= 255} Multicast packets sent with a TTL of
	 * {@code 0} are not transmitted on the network but may be delivered locally.
	 *
	 * @param nativeFD
	 *            the datagram socket file descriptor
	 * @param ttl
	 *            the TTL value to set
	 * @throws NativeIOException
	 *             if an error occurs.
	 * @see {@link NetErrors} for error codes
	 */
	public static native void setTimeToLive(int nativeFD, int ttl) throws NativeIOException;

	/**
	 * Joins or leaves a multicast group.
	 * 
	 * @param fd
	 *            the datagram socket file descriptor
	 * @param join
	 *            join if true, leave if false
	 * @param mcastAddr
	 *            is the multicast address to join
	 * @param mcastAddrLength
	 *            the multicast address size
	 * @param netIfAddr
	 *            is the address of the interface that must join
	 * @param netIfAddrLength
	 *            the interface address size
	 * @throws NativeIOException
	 *             if an error occurs.
	 * @see {@link NetErrors} for error codes
	 */
	public static native void joinOrLeave(int fd, boolean join, byte[] mcastAddr, int mcastAddrLength, byte[] netIfAddr,
			int netIfAddrLength) throws NativeIOException;
}
