/*
 * Copyright (c) 2015, Oracle and/or its affiliates. All rights reserved.
 * Copyright 2015-2023 MicroEJ Corp. This file has been modified and/or created by MicroEJ Corp.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation. The Copyright holder(s) designates
 * this particular file as subject to the "Classpath" exception as provided
 * by the Copyright holder(s) in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact the Copyright holder(s) if you need additional information
 * or have any questions.
 * (if Oracle: 500 Oracle Parkway, Redwood Shores, CA 94065 USA or visit www.oracle.com)
 */

package com.is2t.support.security;

public interface SecurityErrorConstants {

	/** Not an error */
	int J_SEC_NO_ERROR = 0;
	/** End of file */
	int J_EOF = -1;
	/**
	 * The native code has been stopped (with a timeout or not) because result was not available
	 */
	int J_NATIVE_CODE_BLOCKED_WITHOUT_RESULT = -4;
	/**
	 * Dispatch blocking request queue is full and a new request can not be added now
	 */
	int J_BLOCKING_QUEUE_LIMIT_REACHED = -5;
	/** Certificate parsing error */
	int J_CERT_PARSE_ERROR = -6;
	/**
	 * Certificate or key size bigger than the immortal buffer used to process certificates and keys
	 */
	int J_BIG_CERT_OR_KEY_SIZE_ERROR = -7;
	/** No trusted certificate found */
	int J_NO_TRUSTED_CERT = -8;
	/** Basic constraints check failed: intermediate certificate is not a CA certificate */
	int J_NOT_CA_CERT = -9;
	/** Subject/issuer name chaining error */
	int J_NAME_CHAINING_ERROR = -10;
	/** X509 certificate checkValidity error: expired */
	int J_X509_CERT_EXPIRED_ERROR = -11;
	/** X509 certificate checkValidity error: not yet valid */
	int J_X509_CERT_NOT_YET_VALID_ERROR = -12;
	/** RSA wrong block type for RSA function */
	int J_RSA_WRONG_TYPE_ERROR = -21;
	/** RSA buffer error output too small or input too large */
	int J_RSA_BUFFER_ERROR = -22;
	/** Output buffer too small or input too large */
	int J_BUFFER_ERROR = -23;
	/** Setting algo id error */
	int J_ALGO_ID_ERROR = -24;
	/** Setting public key error */
	int J_PUBLIC_KEY_ERROR = -25;
	/** Setting date validity error */
	int J_DATE_ERROR = -26;
	/** Setting subject name error */
	int J_SUBJECT_ERROR = -27;
	/** Setting issuer name error */
	int J_ISSUER_ERROR = -28;
	/** Setting CA basic constraint true error */
	int J_CA_TRUE_ERROR = -29;
	/** Setting extensions error */
	int J_EXTENSIONS_ERROR = -30;
	/** ASN version error invalid number */

	int J_ASN_VERSION_ERROR = -31;
	/** ASN get big int error invalid data */
	int J_ASN_GETINT_ERROR = -32;
	/** ASN key init error invalid input */
	int J_ASN_RSA_KEY_ERROR = -33;
	/** ASN object id error invalid id */
	int J_ASN_OBJECT_ID_ERROR = -34;
	/** ASN tag error not null */
	int J_ASN_TAG_NULL_ERROR = -35;
	/** ASN expect error not zero */
	int J_ASN_EXPECT_0_ERROR = -36;
	/** ASN bit string error wrong id */
	int J_ASN_BITSTR_ERROR = -37;
	/** ASN oid error unknown sum id */
	int J_ASN_UNKNOWN_OID_ERROR = -38;
	/** ASN date error bad size */
	int J_ASN_DATE_SZ_ERROR = -39;
	/** ASN date error current date before */
	int J_ASN_BEFORE_DATE_ERROR = -40;
	/** ASN date error current date after */
	int J_ASN_AFTER_DATE_ERROR = -41;
	/** ASN signature error mismatched oid */
	int J_ASN_SIG_OID_ERROR = -42;
	/** ASN time error unknown time type */
	int J_ASN_TIME_ERROR = -43;
	/** ASN input error not enough data */
	int J_ASN_INPUT_ERROR = -44;
	/** ASN signature error confirm failure */
	int J_ASN_SIG_CONFIRM_ERROR = -45;
	/** ASN signature error unsupported hash type */
	int J_ASN_SIG_HASH_ERROR = -46;
	/** ASN signature error unsupported key type */
	int J_ASN_SIG_KEY_ERROR = -47;
	/** ASN key init error invalid input */
	int J_ASN_DH_KEY_ERROR = -48;
	/** ASN ntru key decode error invalid input */
	int J_ASN_NTRU_KEY_ERROR = -49;
	/** ASN unsupported critical extension */
	int J_ASN_CRIT_EXT_ERROR = -50;
	/** ASN no signer to confirm failure */
	int J_ASN_NO_SIGNER_ERROR = -51;
	/** ASN CRL signature confirm failure */
	int J_ASN_CRL_CONFIRM_ERROR = -52;
	/** ASN CRL no signer to confirm failure */
	int J_ASN_CRL_NO_SIGNER_ERROR = -53;
	/** ASN OCSP signature confirm failure */
	int J_ASN_OCSP_CONFIRM_ERROR = -54;
	/** ECC input argument of wrong type */
	int J_ECC_BAD_ARG_ERROR = -60;
	/** ASN ECC bad input */
	int J_ASN_ECC_KEY_ERROR = -61;
	/** Unsupported ECC OID curve type */
	int J_ECC_CURVE_OID_ERROR = -62;
	/** Bad function argument provided */
	int J_BAD_FUNC_ARG = -63;
	/** Feature not compiled in */
	int J_NOT_COMPILED_IN = -64;
	/** Unicode password too big */
	int J_UNICODE_SIZE_ERROR = -65;
	/** No password provided by user */
	int J_NO_PASSWORD = -66;
	/** alt name size problem too big */
	int J_ALT_NAME_ERROR = -67;

	/** AES-GCM Authentication check failure */
	int J_AES_GCM_AUTH_ERROR = -70;
	/** AES-CCM Authentication check failure */
	int J_AES_CCM_AUTH_ERROR = -71;

	/** Cavium Init type error */
	int J_CAVIUM_INIT_ERROR = -80;
	/** Bad alignment for operation no alloc */
	int J_BAD_ALIGN_ERROR = -81;
	/** Bad ecc enc state operation */
	int J_BAD_ENC_STATE_ERROR = -82;
	/** Bad padding msg not correct length */
	int J_BAD_PADDING_ERROR = -83;
	/** Setting cert request attributes error */
	int J_REQ_ATTRIBUTE_ERROR = -84;
	/** PKCS#7 mismatched OID error */
	int J_PKCS7_OID_ERROR = -85;
	/** PKCS#7 recipient error */
	int J_PKCS7_RECIP_ERROR = -86;
	/** FIPS not allowed error */
	int J_FIPS_NOT_ALLOWED_ERROR = -87;
	/** ASN name constraint error */
	int J_ASN_NAME_INVALID_ERROR = -88;
	/** RNG Failed Reinitialize */
	int J_RNG_FAILURE_ERROR = -89;
	/** FIPS Mode HMAC Minimum Key Length error */
	int J_HMAC_MIN_KEYLEN_ERROR = -90;
	/** RSA Padding Error */
	int J_RSA_PAD_ERROR = -91;
	/** Returning output length only */
	int J_LENGTH_ONLY_ERROR = -92;
	/** In Core Integrity check failure */
	int J_IN_CORE_FIPS_ERROR = -93;
	/** AES KAT failure */
	int J_AES_KAT_FIPS_ERROR = -94;
	/** DES3 KAT failure */
	int J_DES3_KAT_FIPS_ERROR = -95;
	/** HMAC KAT failure */
	int J_HMAC_KAT_FIPS_ERROR = -96;
	/** RSA KAT failure */
	int J_RSA_KAT_FIPS_ERROR = -97;
	/** HASH DRBG KAT failure */
	int J_DRBG_KAT_FIPS_ERROR = -98;
	/** HASH DRBG Continious test failure */
	int J_DRBG_CONT_FIPS_ERROR = -99;
	/** AESGCM KAT failure */
	int J_AESGCM_KAT_FIPS_ERROR = -100;
	/** Process input state error */
	int J_INPUT_CASE_ERROR = -101;
	/** Bad index to key rounds */
	int J_PREFIX_ERROR = -102;
	/** Out of memory */
	int J_MEMORY_ERROR = -103;
	/** Verify problem on finished */
	int J_VERIFY_FINISHED_ERROR = -104;
	/** Verify mac problem */
	int J_VERIFY_MAC_ERROR = -105;
	/** Parse error on header */
	int J_HEADER_PARSE_ERROR = -106;
	/** Don't have enough data to complete task */
	int J_INCOMPLETE_DATA = -110;
	/** Unknown type in record hdr */
	int J_UNKNOWN_RECORD_TYPE = -111;
	/** Error during decryption */
	int J_DECRYPT_ERROR = -112;
	/** recvd alert fatal error */
	int J_FATAL_ERROR = -113;
	/** Error during encryption */
	int J_ENCRYPT_ERROR = -114;
	/** Error during rsa priv op */
	int J_RSA_PRIVATE_ERROR = -118;
	/** Malformed buffer input */
	int J_MALFORMED_BUFFER = -128;
	/** Verify cert error */
	int J_VERIFY_CERT_ERROR = -129;
	/** Verify sign error */
	int J_VERIFY_SIGN_ERROR = -130;

	/** NTRU key error */
	int J_NTRU_KEY_ERROR = -140;
	/** NTRU drbg error */
	int J_NTRU_DRBG_ERROR = -141;
	/** NTRU encrypt error */
	int J_NTRU_ENCRYPT_ERROR = -142;
	/** NTRU decrypt error */
	int J_NTRU_DECRYPT_ERROR = -143;

	/** Bad ECC Curve Type */
	int J_ECC_CURVETYPE_ERROR = -150;
	/** Bad ECC Curve */
	int J_ECC_CURVE_ERROR = -151;
	/** Bad Peer ECC Key */
	int J_ECC_PEERKEY_ERROR = -152;
	/** Bad Make ECC Key */
	int J_ECC_MAKEKEY_ERROR = -153;
	/** Bad ECC Export Key */
	int J_ECC_EXPORT_ERROR = -154;
	/** Bad ECC Shared Secret */
	int J_ECC_SHARED_ERROR = -155;
	/** Not a CA cert error */
	int J_NOT_CA_ERROR = -157;
	/** Bad Cert Manager */
	int J_BAD_CERT_MANAGER_ERROR = -159;
	/** OCSP Certificate revoked */
	int J_OCSP_CERT_REVOKED = -160;
	/** CRL Certificate revoked */
	int J_CRL_CERT_REVOKED = -161;
	/** CRL Not loaded */
	int J_CRL_MISSING = -162;
	/** OCSP need an URL for lookup */
	int J_OCSP_NEED_URL = -165;
	/** OCSP responder doesn't know */
	int J_OCSP_CERT_UNKNOWN = -166;
	/** OCSP lookup not successful */
	int J_OCSP_LOOKUP_FAIL = -167;
	/** Max chain depth exceeded */
	int J_MAX_CHAIN_ERROR = -168;
	/** Suites pointer error */
	int J_SUITES_ERROR = -171;
	/** No PEM header found */
	int J_NO_PEM_HEADER = -172;
	/** Out of order message */
	int J_OUT_OF_ORDER_ERROR = -173;
	/** Bad KEA type found */
	int J_BAD_KEA_TYPE_ERROR = -174;
	/** Sanity check on cipher error */
	int J_SANITY_CIPHER_ERROR = -175;
	/** RXCB returned more than rqed */
	int J_RECV_OVERFLOW_ERROR = -176;
	/** Need peer cert verify Error */
	int J_NO_PEER_VERIFY = -178;
	/** Unrecognized host name Error */
	int J_UNKNOWN_HOST_NAME_ERROR = -181;
	/** Unrecognized max frag len Error */
	int J_UNKNOWN_MAX_FRAG_LEN_ERROR = -182;
	/** KeyUse digSignature error */
	int J_KEYUSE_SIGNATURE_ERROR = -183;
	/** KeyUse keyEncipher error */
	int J_KEYUSE_ENCIPHER_ERROR = -185;
	/** ExtKeyUse server|client_auth */
	int J_EXTKEYUSE_AUTH_ERROR = -186;
	/** Send Cb out of bounds read */
	int J_SEND_OOB_READ_ERROR = -187;
	/** Invalid Renegotiation Info */
	int J_SECURE_RENEGOTIATION_ERROR = -188;
	/** SCR Different cert error */
	int J_SCR_DIFFERENT_CERT_ERROR = -189;
	/** Finished before change cipher */
	int J_NO_CHANGE_CIPHER_ERROR = -190;
	/** Sanity check on msg order error */
	int J_SANITY_MSG_ERROR = -191;
	/** Duplicate message error */
	int J_DUPLICATE_MSG_ERROR = -192;
	/** Unsupported cipher suite */
	int J_UNSUPPORTED_SUITE = -193;
	/** Can't match cipher suite */
	int J_MATCH_SUITE_ERROR = -194;
	/** Bad certificate type */
	int J_BAD_CERTTYPE = -195;
	/** Bad file type */
	int J_BAD_ENCODED_CERT_FORMAT = -196;
	/** Opening random device error */
	int J_OPEN_RAN_ERROR = -197;
	/** Reading random device error */
	int J_READ_RAN_ERROR = -198;
	/** Windows crypt init error */
	int J_WINCRYPT_ERROR = -199;
	/** Windows crypt generation error */
	int J_CRYPTGEN_ERROR = -200;
	/** Reading random device would block */
	int J_RAN_BLOCK_ERROR = -201;
	/** Unknown error */
	int J_UNKNOWN_ERROR = -202;

}
